encode_updates

Function encode_updates 

fn encode_updates<'s, T, D, CB>(
    collection: VecCollection<'s, T, D, Diff>,
    name: &str,
) -> Stream<'s, T, CB::Container>
where T: Timestamp, D: Data, CB: ContainerBuilder + PushInto<(D, T, Diff)> + 'static,
Re-encodes a Vec collection through CB.

For a join implementation that builds its own Vec output and so cannot be handed a container builder.